contexttools.InstrumentMark
===========================

.. inheritance-diagram:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark
   :private-bases:

.. autoclass:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.default_instrument_name

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.default_short_instrument_name

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.effective_context

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.format

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.target_context

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.instrument_name

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.instrument_name_markup

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.short_instrument_name

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.short_instrument_name_markup

Methods
-------

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.attach

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.detach

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__eq__

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__hash__

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__str__

   .. note:: Inherited from `__builtin__.object`
